@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: TheophrastusSettings.py 10388 2017-10-21 15:16:00Z David $
+# $Id: TheophrastusSettings.py 10639 2017-12-12 12:04:16Z David $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2017-10-21 23:16:00 +0800 (Sat, 21 Oct 2017) $
-# $Revision: 10388 $
+# $Date: 2017-12-12 20:04:16 +0800 (Tue, 12 Dec 2017) $
+# $Revision: 10639 $
 
 import os
 
@@ -123,11 +123,11 @@ INSTALLED_APPS = (
     # 'Theophrastus.api',
     # If your want do translate, you need to enable these:
     # 'editor',
-    # 'statistics',
+    'statistics',
     # 'cloud',
-    'newsletter_extension',
-    'document',
-    'integration',
+    # 'newsletter_extension',
+    # 'document',
+    # 'integration',
     # 'api',
 )
 
