@@ -21,7 +21,7 @@ from Iuppiter.Model import BaseModelMixin
 
 from Theophrastus.models import Newsletter, Contact
 
-class CloudMailInformation(models.Model, BaseModelMixin):
+class CloudMailInformation(models.Model):
     """
     Mail sending information.
     """
@@ -34,7 +34,7 @@ class CloudMailInformation(models.Model, BaseModelMixin):
     # Response message for sent mail.
     message = models.TextField(default='')
 
-class NewsletterInformation(models.Model, BaseModelMixin):
+class NewsletterInformation(models.Model):
 
     newsletter = models.ForeignKey(Newsletter, unique=True)
 
