@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 10662 2017-12-19 10:11:52Z David $
+# $Id: admin.py 10642 2017-12-16 19:53:11Z David $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,10 +12,11 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2017-12-19 18:11:52 +0800 (Tue, 19 Dec 2017) $
-# $Revision: 10662 $
+# $Date: 2017-12-17 03:53:11 +0800 (Sun, 17 Dec 2017) $
+# $Revision: 10642 $
 
 from django.contrib import admin
+from django.contrib.contenttypes import generic
 
 from emencia.django.newsletter.models import Newsletter
 
@@ -23,12 +24,34 @@ from Theophrastus.newsletter_extension.models import Header, Footer
 from Theophrastus.newsletter_extension.forms import HeaderTinyMCEForm
 from Theophrastus.newsletter_extension.forms import FooterTinyMCEForm
 
+class NewsletterHeaderline(generic.GenericTabularInline): #or generic.GenericStackedInline, this has different visual layout.
+    model = Newsletter
+
+    ct_field = "headerContentType"
+    ct_fk_field = "headerId"
+    fk_name = "header"
+
+class NewsletterFooterline(generic.GenericTabularInline): #or generic.GenericStackedInline, this has different visual layout.
+    model = Newsletter
+
+    ct_field = "footerContentType"
+    ct_fk_field = "footerId"
+    fk_name = "footer"
+
 class HeaderTinyMCEAdmin(admin.ModelAdmin):
     form = HeaderTinyMCEForm
 
+    inlines = [
+        NewsletterHeaderline,
+    ]
+
 admin.site.register(Header, HeaderTinyMCEAdmin)
 
 class FooterTinyMCEAdmin(admin.ModelAdmin):
     form = FooterTinyMCEForm
+    inlines = [
+        NewsletterFooterline,
+    ]
+
 
 admin.site.register(Footer, FooterTinyMCEAdmin)
