@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 10436 2017-11-05 03:14:46Z David $
+# $Id: views.py 10452 2017-11-07 08:45:22Z David $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -13,7 +13,7 @@
 #
 # $Author: David $
 # $Date: 2013-01-30 12:13:45 +0800$
-# $Revision: 10436 $
+# $Revision: 10452 $
 
 from django.shortcuts import render_to_response, get_object_or_404
 from django.utils.translation import ugettext_lazy as _
@@ -162,6 +162,7 @@ def resendErrorContact(request, newsletterId):
     return render_to_response('newsletter/newsletter_historic.html',
                               context, context_instance=RequestContext(request))
 
+
 def viewErrorDetails(request, slug, contactMailingStatusId):
     """
     Display the error message of a newsletter contact.
@@ -176,19 +177,26 @@ def viewErrorDetails(request, slug, contactMailingStatusId):
     opts = Newsletter._meta
     cloudSrv = CloudService.getInstance()
     newsletter = get_object_or_404(Newsletter, slug=slug)
-    obj = cloudSrv.getCloudMailInformation(
-        newsletter_id=contactMailingStatus.newsletter.id,
-        contact_id=contactMailingStatus.contact.id,
-        errorOnNotFound=False
-    )
+
+    if contactMailingStatus.status == ContactMailingStatus.ERROR:
+        content = ErrorMessage.objects.filter(
+            newsletter=contactMailingStatus.newsletter,
+            contact=contactMailingStatus.contact
+        )[0].message
+    else:
+        content = cloudSrv.getCloudMailInformation(
+            newsletter_id=contactMailingStatus.newsletter.id,
+            contact_id=contactMailingStatus.contact.id,
+            errorOnNotFound=False
+        ).message
     
     context = {
-        'title': _('Error of contact: %s') % obj.contact_id,
+        'title': _('Error of contact: %s') % contactMailingStatus.contact.email,
         'original': newsletter,
         'opts': opts,
         'object_id': newsletter.pk,
         'app_label': opts.app_label,
-        'content': obj.message
+        'content': content
     }
     return render_to_response(
         'NewsletterHistoricErrorDetail.html',
@@ -196,4 +204,3 @@ def viewErrorDetails(request, slug, contactMailingStatusId):
         context_instance=RequestContext(request)
     )
 
-
